/*
 *  Copyright (c) 2016 Dmitry Kazakov <dimula73@gmail.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#ifndef __KIS_SHAPE_COMMANDS_TEST_H
#define __KIS_SHAPE_COMMANDS_TEST_H

#include <QtTest>

class KisShapeCommandsTest : public QObject
{
    Q_OBJECT
    void testResizeShape(bool normalizeGroup);

private Q_SLOTS:
    void testGrouping();
    void testResizeShape();
    void testResizeShapeNormalized();

    void testResizeNullShape();
    void testResizeNullShapeGlobal();
    void testScaleNullShape();
    void testScaleNullShapeCovered();
    void testScaleNullShapeGlobal();
};

#endif /* __KIS_SHAPE_COMMANDS_TEST_H */
